FILE:		Tpros.man
DESCRIPTION:    Manual on the application of Tpros to the Austenite data
AUTHOR:		Dr. Franck Tancret / C.A. Walsh
LAST MOD DATE:	25/03/99


Tpros is the Gaussian Process program written by Mark Gibbs and David MacKay. This 
file describes the application of this program to predict the Ac1 and Ac3 
austenitization temperatures of steels.

##################################################################################
 1.                         Introduction to the Problem                     
##################################################################################

The problem we are interested in is that of predicting the temperatures at which 
Austenite starts to form (Ac1) and that at which Austenite formation is complete 
(Ac3) during the continuous heating of a steel alloy. This prediction is made as a 
function of the heating rate and the elemental composition. The modelling procedure
is a purely empirical one; i.e. the model is trained on a set of experimental data 
for which the "outputs" are known, and creates a kind of non-linear, 
multi-parameter "regression" of the outputs versus the inputs. This "regression" 
has already been produced and the model is delivered ready to perform predictions 
for steels of any desired composition (within certain specified limits). A perusal 
of the paper by Bailer-Jones et al. [1] is strongly recommended before proceeding 
further. It provides details about the model and its use; a copy is available in 
the file gpaus.ps.


##################################################################################
 2.                      Downloading Tpros and Data Files                  
##################################################################################

MAP provides a set of data files which can be used with the Tpros program for 
calculating the temperatures Ac1 and Ac3. The Tpros program itself is not included 
with this distribution, as we do not maintain it. We cannot, therefore, be 
responsible for any failures due to backward compatibility with later versions of 
Tpros. 

2.1 The Tpros program.
----------------------

Tpros is an ANSI C program for UNIX/Linux machines. It can be downloaded from the 
following web site:

          http://wol.ra.phy.cam.ac.uk/mng10/GP/GP.html

It is in the form of a zipped TAR file (Tpros.tar.gz), which is best placed in a 
separate directory (e.g. /gauss) before uncompressing it. To uncompress the file 
type:

gunzip Tpros.tar.gz	(creates the Tpros.tar file)

and then:

tar -xvf Tpros.tar	(extracts the entire Tpros package)

It contains 7 directories:

/ansi           - Contains several subroutine source libraries and definition
                  files which are absolutely essential for the program.
/bini386        - Contains the executable Tpros program for Linux PCs.
/binsun4        - Contains the executable Tpros program for Sun 4.          
/binsun5        - Contains the executable Tpros program for Sun 5. 
/example        - Contains typical examples; not used for this application.
/spec           - Contains typical specification files; not used for this
                  application.
/weld-toughness - Contains typical examples; not used for this application.

and several files:

Makefile  - The makefile for compiling the program Tpros.c.
randfile  - Absolutely essential for running the software.
README    - A "Readme" file... please read it!
TManual   - Document providing information about Gaussian Processes and
	    Tpros. Very helpful for further use of the software. 
Tpros.c   - The Tpros source code in C.
Tspec     - Typical specification files; not used for this application.
Tspec14   - Typical specification files; not used for this application


                           *** IMPORTANT ***
Place the appropriate version of the Tpros executable file into the Tpros parent 
directory (in this case /gauss). If neither of these versions is suitable, the 
source code can be recompiled using the Makefile.


2.2 The Data Files from MAP
---------------------------

The acpros.tar file from MAP contains the following files:

acpros.f         - A FORTRAN program for un-normalising the output data files.
acpros.man       - This manual.
gpaus.ps         - A postscript file of the paper in reference 1.
h.ac1            - Hyperparameters file for Ac1 predictions.
h.ac3            - Hyperparameters file for Ac3 predictions.
inputs.norm      - Normalised inputs file (composition of steels
		   and heating rates).
min-max	         - Minimum and maximum values for the wt% of each element and 
                   the heating rate (K/s) used in the original database. (i.e. 
                   the minimum and maximum values of each column in the original
                   database before normalisation.
output.ac1.norm  - Normalised Ac1 values.
output.ac3.norm  - Normalised Ac3 values.
Tspec.pred.ac1   - Tpros specification file for Ac1 predictions.
Tspec.pred.ac3   - Tpros specification file for Ac3 predictions.


The following files are essential for using the Tpros program for predicting the 
Ac1 and Ac3 temperatures, and should be placed in the parent Tpros directory with 
the Tpros executable program:

h.ac1
h.ac3
inputs.norm
output.ac1.norm
output.ac3.norm
Tspec.pred.ac1
Tspec.pred.ac3

These files should not be changed. The file inputs.norm contains 788 lines of 
normalised data, specifying a range of different steel compositions and heating 
rates. The files output.ac1.norm and output.ac3.norm contain the experimentally 
determined values for the temperatures Ac1 and Ac3 for each entry in the 
inputs.norm file. These files were fed into the Gaussian Process model, which 
produced as output the files h.ac1 and h.ac3, containing the parameters of the 
non-linear, multi-parameter fit to the data. The Tpros program uses these for 
predicting values of Ac1 and Ac3 for other steel compositions and heating rates.

The order of the variables in the *.norm files are specified in the file min-max.
Each input and output variable has been linearly normalised to lie in the range 
-0.5 to +0.5 (see Reference 1 and the file min-max for details).

inputs.norm		12 columns, 788 lines. The input data.
output.ac1.norm		1 column, 788 lines. The Ac1 output data.
output.ac3.norm		1 column, 788 lines. The Ac3 output data.



##################################################################################
3.                Creating an Input File for the Tpros Program
##################################################################################

The composition and heating rates of the steels for which predictions of Ac1 and 
Ac3 are to be made, should be placed into a file as follows (see also the file 
min-max):

Each line of data corresponds to a different steel composition or heating rate. 
(There is no restriction on the number of lines of data in the input file.)

For each steel, 12 data items must be specified:

Column number	    Variable

    1		normalised C  wt.%
    2		normalised Si wt.%	
    3		normalised Mn wt.%	
    4		normalised Cu wt.%	
    5		normalised Ni wt.%	
    6		normalised Cr wt.%	
    7		normalised Mo wt.%	
    8		normalised Nb wt.%	
    9		normalised V  wt.%	
   10		normalised W  wt.%	
   11		normalised Co wt.%	
   12		normalised Heating rate (K/s)


The actual composition (in wt%) must be normalised using the equation:

normalised value =  (value - Min)    - 0.5
                     ------------
                     (Max - Min)


where the values for Min and Max are defined as follows:
		
Column number	Variable	Min	Max

      1		C (wt.%)	0	0.96
      2		Si  ,,		0	2.13
      3		Mn  ,,		0	3.06
      4		Cu  ,,		0	2.01
      5		Ni  ,,		0	9.12
      6		Cr  ,,		0	17.98
      7		Mo  ,,		0	4.80
      8		Nb  ,,		0	0.17
      9		V   ,,		0	2.45
     10		W   ,,		0	8.59
     11		Co  ,,		0	4.07
     12		Heating rate	0.03	50
		(K/s)



A sample data file
------------------

For a set of steels with the following wt % and heating rates: 

   C   Si    Mn  Cu   Ni   Cr   Mo  Nb    V   W  Co Heating rate (K/s)
 0.3  0.25  0.7   0  3.5    0    0   0    0   0   0      5
 0.3  0.25  0.7   0  3.5    0    0   0    0   0   0     25
 0.5  0.28  0.8   0  1.2  0.8    0   0    0   0   0      5
 0.5  0.28  0.8   0  1.2  0.8    0   0    0   0   0     25
 0.6  2.00  0.9   0    0    0    0   0    0   0   0      5
 0.6  2.00  0.9   0    0    0    0   0    0   0   0     25
 0.2  0.25  0.8   0    0  0.7    0   0  0.2   0   0      5
 0.2  0.25  0.8   0    0  0.7    0   0  0.2   0   0     25
 0.2  0.20  0.9   0  0.5  0.5  0.2   0    0   0   0      5
 0.2  0.20  0.9   0  0.5  0.5  0.2   0    0   0   0     25

The input file is:

-0.1875 -0.3826 -0.2712 -0.5 -0.1162 -0.5000 -0.5000 -0.5 -0.5000 -0.5 -0.5 -0.4
-0.1875 -0.3826 -0.2712 -0.5 -0.1162 -0.5000 -0.5000 -0.5 -0.5000 -0.5 -0.5  0.0
 0.0208 -0.3685 -0.2386 -0.5 -0.3684 -0.4555 -0.5000 -0.5 -0.5000 -0.5 -0.5 -0.4
 0.0208 -0.3685 -0.2386 -0.5 -0.3684 -0.4555 -0.5000 -0.5 -0.5000 -0.5 -0.5  0.0
 0.1250  0.4390 -0.2059 -0.5 -0.5000 -0.5000 -0.5000 -0.5 -0.5000 -0.5 -0.5 -0.4
 0.1250  0.4390 -0.2059 -0.5 -0.5000 -0.5000 -0.5000 -0.5 -0.5000 -0.5 -0.5  0.0
-0.2917 -0.3826 -0.2386 -0.5 -0.5000 -0.4611 -0.5000 -0.5 -0.4184 -0.5 -0.5 -0.4
-0.2917 -0.3826 -0.2386 -0.5 -0.5000 -0.4611 -0.5000 -0.5 -0.4184 -0.5 -0.5  0.0
-0.2917 -0.4061 -0.2059 -0.5 -0.4452 -0.4722 -0.4583 -0.5 -0.5000 -0.5 -0.5 -0.4
-0.2917 -0.4061 -0.2059 -0.5 -0.4452 -0.4722 -0.4583 -0.5 -0.5000 -0.5 -0.5  0.0



##################################################################################
4.                         Running the Tpros Program
##################################################################################

The input file (see section 3.) should be placed in the Tpros parent directory along
with the executable program and the other required data files (see section 2.). The 
command line for running Tpros is of the form:

Tpros (Tspec filename) -hi (hyperparameter filename) -ninter (no. of lines of input 
data) -int_gf (input data filename) -int_of (output filename)


If the name of the input file is 'pred.norm' and has 10 lines of data (as in section
3 above), a suitable command line for running the Tpros program is then

Tpros Tspec.pred.ac1 -hi h.ac1 -ninter 10 -int_gf pred.norm -int_of pred.ac1.norm

for calculations of the Ac1 temperatures, and

Tpros Tspec.pred.ac3 -hi h.ac3 -ninter 10 -int_gf pred.norm -int_of pred.ac3.norm

for calculations of the Ac3 temperatures. The output files pred.ac3.norm and 
pred.ac1.norm are produced which contain the calculated temperatures in normalised 
form.

Predictions can take several hours... or days, depending on the length of
you input file, and the power of your computer!


##################################################################################
5.                             The Output Files
##################################################################################

Two output files are produced by the Tpros program:

pred.ac1.norm    -   contains the predicted values for Ac1
pred.ac3.norm    -   contains the predicted values for Ac3

Each output file contains 1 line of 5 data items for each line of input data:

column 1 - the normalised predicted Ac1 or Ac3 temperature.
column 2 - the 1-sigma error bar, which includes both the experimental noise
           of the database and an estimation of the prediction uncertainty.
column 3 - the predicted output minus the 1-sigma error.
column 4 - the predicted output plus the 1-sigma error.
column 5 - an estimation of the noise level in the database; it is the same for
           all lines.

The normalised values for the temperatures in columns 1, 3 and 4, must be 
un-normalised using the equation:

       actual value = [(normalised value + 0.5)*(Max - Min)] + Min

The values in column 2 can be un-normalised using the equation:

            actual value = normalised value * (Max - Min)

The values of Min and Max for Ac1 and Ac3 are:

                                Min      Max
		Ac1 (C)	530	 921
		Ac3 (C)	651	1060

The FORTRAN program, acpros.f, can be used to translate the output files to produce
the actual values of the temperatures. 



Sample Output - Ac1
-------------------------
When running the Tpros program the following is output to the screen:


Tpros : GP training program
===========================

(c)1996,1997 M N Gibbs and D J C MacKay

Version 6.2


specfile    : Tspec.pred.ac1
datafile    : output.ac1.norm
gridfile    : inputs.norm
outfile     : pred.ac1.norm
hypinfile       : h.ac1

Parameter values

SEED                             : 175
no. of initial data points       : 788
no. of dimensions in input space : 12
no. of gaussians in cov fn       : 1
order of polynomials for l.s.    : 1


igridfile                        : pred.norm
Method used for inversion (INT)  : LUd
no. of interpolation points      : 10
no. of s.d. for error bars       : 1
Calculate Error Bars             : yes
Calculate noise                  : yes


no. of hidden neurons noise : 1

Train Error  : 0.852206

                               ------------------

A sample output file pred.ac1.norm, obtained using the sample input file in
section 3., is:

-0.183674 0.042349 -0.226022 -0.141325 0.037178 
-0.108153 0.089333 -0.197487 -0.018820 0.037178 
-0.019106 0.041362 -0.060468  0.022256 0.037178 
 0.058113 0.078147 -0.020034  0.136260 0.037178 
 0.043198 0.045568 -0.002370  0.088766 0.037178 
 0.047780 0.094182 -0.046402  0.141962 0.037178 
 0.029018 0.042070 -0.013051  0.071088 0.037178 
 0.095363 0.074785  0.020578  0.170148 0.037178 
-0.006991 0.041036 -0.048028  0.034045 0.037178 
 0.063722 0.078547 -0.014825  0.142269 0.037178 

This output data can be translated using the formulae given above or with the
FORTRAN progran acpros.f to give the actual values for Ac1:

  Ac1 (deg.C)     error     Range of values for Ac1 (deg. C)
   653.68         16.56           637.13  -   670.24
   683.21         34.93           648.28  -   718.14
   718.03         16.17           701.86  -   734.20
   748.22         30.56           717.67  -   778.78
   742.39         17.82           724.57  -   760.21
   744.18         36.83           707.36  -   781.01
   736.85         16.45           720.40  -   753.30
   762.79         29.24           733.55  -   792.03
   722.77         16.05           706.72  -   738.81
   750.42         30.71           719.70  -   781.13



Sample Output - Ac3
-------------------------
When running the Tpros program the following is output to the screen:

Tpros : GP training program
===========================

(c)1996,1997 M N Gibbs and D J C MacKay

Version 6.2


specfile    : Tspec.pred.ac3
datafile    : output.ac3.norm
gridfile    : inputs.norm
outfile     : pred.ac3.norm
hypinfile       : h.ac3

Parameter values

SEED                             : 175
no. of initial data points       : 788
no. of dimensions in input space : 12
no. of gaussians in cov fn       : 1
order of polynomials for l.s.    : 1


igridfile                        : pred.norm
Method used for inversion (INT)  : LUd
no. of interpolation points      : 10
no. of s.d. for error bars       : 1
Calculate Error Bars             : yes
Calculate noise                  : yes


no. of hidden neurons noise : 1

Train Error  : 1.090533

                               ------------------

A sample output file pred.ac3.norm, obtained using the sample input file in 
section 3., is:

-0.251874 0.047269 -0.299143 -0.204605 0.041144 
-0.143653 0.097767 -0.241419 -0.045886 0.041144 
-0.225746 0.048309 -0.274055 -0.177436 0.041144 
-0.155057 0.108816 -0.263873 -0.046240 0.041144 
-0.112735 0.050867 -0.163603 -0.061868 0.041144 
-0.083389 0.113261 -0.196650  0.029872 0.041144 
 0.000276 0.050614 -0.050339  0.050890 0.041144 
 0.083990 0.082258  0.001732  0.166248 0.041144 
-0.042046 0.045748 -0.087794  0.003702 0.041144 
 0.032149 0.093647 -0.061498  0.125797 0.041144 

This output data can be translated using the formulae given above or with the
FORTRAN progran acpros.f to give the actual values for Ac3:

  Ac3 (deg.C)     error     Range of values for Ac3 (deg. C)
   752.48         19.33           733.15  -   771.82
   796.75         39.99           756.76  -   836.73
   763.17         19.76           743.41  -   782.93
   792.08         44.51           747.58  -   836.59
   809.39         20.80           788.59  -   830.20
   821.39         46.32           775.07  -   867.72
   855.61         20.70           834.91  -   876.31
   889.85         33.64           856.21  -   923.50
   838.30         18.71           819.59  -   857.01
   868.65         38.30           830.35  -   906.95



##################################################################################
6.                 References and Other Sources of Information                    
##################################################################################

1. Bailer-Jones, C.A.L., Bhadeshia, H.K.D.H., and MacKay, D.J.C., 1999, 
   Materials Science and Technology, vol. , . (in press)
   "Gaussian Process Modelling of Austenite Formation in Steel."

   This paper explains the austenite modelling problem, the dataset, the
   basics of Gaussian Process modelling, as well as presenting results from
   its use. A copy of the paper can be found in the file gpaus.ps, and is available
   on the web at http://www.msm.cam.ac.uk/phase-trans/abstracts/gaussian.html.


Further information about Gaussian Processes can be obtained from:

2. The references in reference 1.
3. Mark Gibbs' Gaussian Processes web page: 
            http://wol.ra.phy.cam.ac.uk/mng10/GP/GP.html
   The Tpros software can also be downloaded from here.
4. David MacKay's Gaussian Processes web page:
            http://wol.ra.phy.cam.ac.uk/mackay/GP/
5. A short summary by Coryn Bailer-Jones:
            http://www.mpia-hd.mpg.de/stars/calj/gp_sum.ps.gz

More details on Austenite can be found in the paper:

6. L. Gavard, H.K.D.H. Bhadeshia, D.J.C. MacKay and S. Suzuki, Materials
   Science and Technology, June 1996, vol. 12, pp. 453-463.
   "A Bayesian Neural Network Model for Austenite Formation in Steels",

and references therein. 


